@@ -15,59 +15,80 @@ class RestProxyAdmin(KafkaAdmin):
 
     # ACLs
 
-    def acls(self, restype="any", name=None, resource_pattern_type="any", principal=None, host=None, operation="any", permission_type="any"):
+    def acls(self, acl_dict={}):
         (rest_proxy_url_str, auth_str_tuple) = self.restproxy_obj.get_url_str_auth_str_tuple_tuple()
         #
         url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/acls"
         headers_dict = {"Content-Type": "application/json"}
         #
-        payload_dict = {"resource_type": restype, "pattern_type": resource_pattern_type, "operation": operation, "permission": permission_type}
-        if name is not None:
-            payload_dict["resource_name"] = name
-        if principal is not None:
-            payload_dict["principal"] = principal
-        if host is not None:
-            payload_dict["host"] = host 
+        resource_type_str = acl_dict["resource_type"] if "resource_type" in acl_dict else None
+        name_str = acl_dict["name"] if "name" in acl_dict else None
+        pattern_type_str = acl_dict["pattern_type"] if "pattern_type" in acl_dict else None
+        principal_str = acl_dict["principal"] if "principal" in acl_dict else None
+        host_str = acl_dict["host"] if "host" in acl_dict else None
+        operation_str = acl_dict["operation"] if "operation" in acl_dict else None
+        permission_type_str = acl_dict["permission_type"] if "permission_type" in acl_dict else None
         #
-        response_dict = get(url_str, headers_dict, payload_dict=payload_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+        payload_dict = {}
+        if resource_type_str is not None:
+            payload_dict["resource_type"] = resource_type_str
+        if name_str is not None:
+            payload_dict["name"] = name_str
+        if pattern_type_str is not None:
+            payload_dict["pattern_type"] = pattern_type_str
+        if principal_str is not None:
+            payload_dict["principal"] = principal_str
+        if host_str is not None:
+            payload_dict["host"] = host_str
+        if operation_str is not None:
+            payload_dict["operation"] = operation_str
+        if permission_type_str is not None:
+            payload_dict["permission"] = permission_type_str
+        #
+        response_dict = get(url_str, headers_dict, payload_dict=payload_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
         kafkaAcl_dict_list = response_dict["data"]
         #
-        dict_list = [kafkaAcl_dict_to_dict(kafkaAcl_dict) for kafkaAcl_dict in kafkaAcl_dict_list]
-        return dict_list
+        acl_dict_list = [kafkaAcl_dict_to_acl_dict(kafkaAcl_dict) for kafkaAcl_dict in kafkaAcl_dict_list]
+        return acl_dict_list
 
-    def create_acl(self, restype="any", name=None, resource_pattern_type="any", principal=None, host=None, operation="any", permission_type="any"):
+    def create_acl(self, acl_dict):
         (rest_proxy_url_str, auth_str_tuple) = self.restproxy_obj.get_url_str_auth_str_tuple_tuple()
         #
         url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/acls"
         headers_dict = {"Content-Type": "application/json"}
         #
-        payload_dict = {"resource_type": restype.upper(), "pattern_type": resource_pattern_type.upper(), "operation": operation.upper(), "permission": permission_type.upper()}
-        if name is not None:
-            payload_dict["resource_name"] = name
-        if principal is not None:
-            payload_dict["principal"] = principal
-        if host is not None:
-            payload_dict["host"] = host 
+        payload_dict = {"resource_type": acl_dict["resource_type"].upper(), "resource_name": acl_dict["name"], "pattern_type": acl_dict["pattern_type"].upper(), "principal": acl_dict["principal"], "host": acl_dict["host"], "operation": acl_dict["operation"].upper(), "permission": acl_dict["permission_type"].upper()}
         #
-        post(url_str, headers_dict, payload_dict=payload_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+        post(url_str, headers_dict, payload_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
+        #
+        return acl_dict
 
-    def delete_acl(self, restype="any", name=None, resource_pattern_type="any", principal=None, host=None, operation="any", permission_type="any"):
+    def delete_acls(self, acl_dict):
         (rest_proxy_url_str, auth_str_tuple) = self.restproxy_obj.get_url_str_auth_str_tuple_tuple()
         #
-        url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/acls?resource_type={restype.upper()}&pattern_type={resource_pattern_type.upper()}&operation={operation.upper()}&permission={permission_type.upper()}"
-        if name is not None:
-            url_str += f"&resource_name={name}"
-        if principal is not None:
-            url_str += f"&principal={principal}"
-        if host is not None:
-            url_str += f"&host={host}"         
+        url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/acls?"
+        #
+        if "resource_type" in acl_dict and acl_dict["resource_type"] is not None:
+            url_str += f"&resource_type={acl_dict['resource_type'].upper()}"
+        if "name" in acl_dict and acl_dict["name"] is not None:
+            url_str += f"&resource_name={acl_dict['name']}"
+        if "pattern_type" in acl_dict and acl_dict["pattern_type"] is not None:
+            url_str += f"&pattern_type={acl_dict['pattern_type'].upper()}"
+        if "principal" in acl_dict and acl_dict["principal"] is not None:
+            url_str += f"&principal={acl_dict['principal']}"
+        if "host" in acl_dict and acl_dict["host"] is not None:
+            url_str += f"&host={acl_dict['host']}"
+        if "operation" in acl_dict and acl_dict["operation"] is not None:
+            url_str += f"&operation={acl_dict['operation'].upper()}"
+        if "permission_type" in acl_dict and acl_dict["permission_type"] is not None:
+            url_str += f"&permission={acl_dict['permission_type'].upper()}"
         #
         headers_dict = {"Content-Type": "application/json"}
-        response_dict = delete(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+        response_dict = delete(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
         kafkaAcl_dict_list = response_dict["data"]
         #
-        dict_list = [kafkaAcl_dict_to_dict(kafkaAcl_dict) for kafkaAcl_dict in kafkaAcl_dict_list]
-        return dict_list
+        acl_dict_list = [kafkaAcl_dict_to_acl_dict(kafkaAcl_dict) for kafkaAcl_dict in kafkaAcl_dict_list]
+        return acl_dict_list
 
     # Brokers
 
@@ -83,7 +104,7 @@ class RestProxyAdmin(KafkaAdmin):
         #
         url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/brokers"
         headers_dict = {"Content-Type": "application/json"}
-        response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+        response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
         kafkaBroker_dict_list = response_dict["data"]
         #
         broker_dict = {kafkaBroker_dict["broker_id"]: kafkaBroker_dict["host"] + ":" + str(kafkaBroker_dict["port"]) for kafkaBroker_dict in kafkaBroker_dict_list if any(fnmatch(str(kafkaBroker_dict["broker_id"]), pattern_str) for pattern_str in pattern_str_list)}
@@ -103,11 +124,11 @@ class RestProxyAdmin(KafkaAdmin):
             #
             dict_list = [{"name": key_str, "value": value_str} for key_str, value_str in config_dict.items()]
             payload_dict = {"data": dict_list}
-            post(url_str, headers_dict, payload_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+            post(url_str, headers_dict, payload_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
         #        
         url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/broker-configs"
         headers_dict = {"Content-Type": "application/json"}
-        response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+        response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
         kafkaClusterConfig_dict_list = response_dict["data"]
         #
         cluster_config_dict = {}
@@ -136,7 +157,7 @@ class RestProxyAdmin(KafkaAdmin):
         for group_str, group_description_dict in group_str_group_description_dict_dict.items():
             url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/consumer-groups/{group_str}/consumers"
             headers_dict = {"Content-Type": "application/json"}
-            response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+            response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
             kafkaConsumer_dict_list = response_dict["data"]
             #
             dict_list = [{"member_id": kafkaConsumer_dict["consumer_id"], "client_id": kafkaConsumer_dict["client_id"], "host": kafkaConsumer_dict["cluster_id"], "group_instance_id": kafkaConsumer_dict["instance_id"]} for kafkaConsumer_dict in kafkaConsumer_dict_list]
@@ -144,7 +165,7 @@ class RestProxyAdmin(KafkaAdmin):
                 consumer_id_str = dict["member_id"]
                 url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/consumer-groups/{group_str}/consumers/{consumer_id_str}/assignments"
                 headers_dict = {"Content-Type": "application/json"}
-                response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+                response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
                 kafkaConsumerAssignment_dict_list = response_dict["data"]
                 #
                 dict["topic_partitions"] = [{"error": None, "metadata": None, "offset": None, "partition": kafkaConsumerAssignment_dict["partition_id"], "topic": kafkaConsumerAssignment_dict["topic_name"]} for kafkaConsumerAssignment_dict in kafkaConsumerAssignment_dict_list]
@@ -166,39 +187,43 @@ class RestProxyAdmin(KafkaAdmin):
 
     def group_offsets(self, pattern, group_offsets=None, state_pattern="*"):
         pattern_str_list = [pattern] if isinstance(pattern, str) else pattern
+        group_offsets_dict = group_offsets
         state_pattern_str_list = [state_pattern] if isinstance(pattern, str) else state_pattern
         #
-        kafkaConsumerGroup_dict_list = self.get_kafkaConsumerGroup_dict_list(pattern_str_list)
-        #
-        group_str_list = [kafkaConsumerGroup_dict["consumer_group_id"] for kafkaConsumerGroup_dict in kafkaConsumerGroup_dict_list if any(fnmatch(kafkaConsumerGroup_dict["consumer_group_id"], pattern_str) for pattern_str in pattern_str_list) and any(fnmatch(kafkaConsumerGroup_dict["state"], state_pattern_str.upper()) for state_pattern_str in state_pattern_str_list)]
-        #
-        (rest_proxy_url_str, auth_str_tuple) = self.restproxy_obj.get_url_str_auth_str_tuple_tuple()
-        #
-        group_offsets = {}
-        headers_dict = {"Content-Type": "application/json"}
-        for group_str in group_str_list:
-            url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/consumer-groups/{group_str}/lags"
-            response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
-            kafkaConsumerLag_dict_list = response_dict["data"]
+        if group_offsets_dict is not None:
+            raise Exception(f"group_offsets() with group_offsets != None not supported for REST Proxy.")
+        else:
+            kafkaConsumerGroup_dict_list = self.get_kafkaConsumerGroup_dict_list(pattern_str_list)
             #
-            if group_str in group_offsets:
-                topic_str_offsets_dict_dict = group_offsets[group_str]
-            else:
-                topic_str_offsets_dict_dict = {}
+            group_str_list = [kafkaConsumerGroup_dict["consumer_group_id"] for kafkaConsumerGroup_dict in kafkaConsumerGroup_dict_list if any(fnmatch(kafkaConsumerGroup_dict["consumer_group_id"], pattern_str) for pattern_str in pattern_str_list) and any(fnmatch(kafkaConsumerGroup_dict["state"], state_pattern_str.upper()) for state_pattern_str in state_pattern_str_list)]
             #
-            for kafkaConsumerLag_dict in kafkaConsumerLag_dict_list:
-                topic_str = kafkaConsumerLag_dict["topic_name"]
-                partition_int = kafkaConsumerLag_dict["partition_id"]
-                offset_int = kafkaConsumerLag_dict["current_offset"]
-                if topic_str in topic_str_offsets_dict_dict:
-                    offsets_dict = topic_str_offsets_dict_dict[topic_str]
-                else:
-                    offsets_dict = {}
+            (rest_proxy_url_str, auth_str_tuple) = self.restproxy_obj.get_url_str_auth_str_tuple_tuple()
+            #
+            group_offsets = {}
+            headers_dict = {"Content-Type": "application/json"}
+            for group_str in group_str_list:
+                url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/consumer-groups/{group_str}/lags"
+                response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
+                kafkaConsumerLag_dict_list = response_dict["data"]
                 #
-                offsets_dict[partition_int] = offset_int
-                topic_str_offsets_dict_dict[topic_str] = offsets_dict
-            #
-            group_offsets[group_str] = topic_str_offsets_dict_dict
+                if group_str in group_offsets:
+                    topic_str_offsets_dict_dict = group_offsets[group_str]
+                else:
+                    topic_str_offsets_dict_dict = {}
+                #
+                for kafkaConsumerLag_dict in kafkaConsumerLag_dict_list:
+                    topic_str = kafkaConsumerLag_dict["topic_name"]
+                    partition_int = kafkaConsumerLag_dict["partition_id"]
+                    offset_int = kafkaConsumerLag_dict["current_offset"]
+                    if topic_str in topic_str_offsets_dict_dict:
+                        offsets_dict = topic_str_offsets_dict_dict[topic_str]
+                    else:
+                        offsets_dict = {}
+                    #
+                    offsets_dict[partition_int] = offset_int
+                    topic_str_offsets_dict_dict[topic_str] = offsets_dict
+                #
+                group_offsets[group_str] = topic_str_offsets_dict_dict
         #
         return group_offsets
 
@@ -219,7 +244,7 @@ class RestProxyAdmin(KafkaAdmin):
                 key_str_value_str_dict_list = [{"name": config_key_str, "value": config_value_str} for config_key_str, config_value_str in config_dict.items()]
                 payload_dict = {"data": key_str_value_str_dict_list}
                 #
-                post(url_str, headers_dict, payload_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+                post(url_str, headers_dict, payload_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
         #
         def kafkaTopicConfigList_dict_to_config_dict(kafkaTopicConfigList_dict):
             config_dict = {}
@@ -234,7 +259,7 @@ class RestProxyAdmin(KafkaAdmin):
             return config_dict
 
         #
-        topic_str_config_dict_dict = {topic_str: kafkaTopicConfigList_dict_to_config_dict(get(f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/topics/{topic_str}/configs", None, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())) for topic_str in topic_str_list}
+        topic_str_config_dict_dict = {topic_str: kafkaTopicConfigList_dict_to_config_dict(get(f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/topics/{topic_str}/configs", None, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)) for topic_str in topic_str_list}
         #
         return topic_str_config_dict_dict
     
@@ -252,7 +277,7 @@ class RestProxyAdmin(KafkaAdmin):
         headers_dict = {"Content-Type": "application/json"}
         configs_dict_list = [{"name": config_key_str, "value": config_value_str} for config_key_str, config_value_str in config_dict.items()]
         payload_dict = {"topic_name": topic_str, "partitions_count": partitions_int, "configs": configs_dict_list}
-        post(url_str, headers_dict, payload_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+        post(url_str, headers_dict, payload_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
         #
         return topic_str
 
@@ -265,7 +290,7 @@ class RestProxyAdmin(KafkaAdmin):
             for topic_str in topic_str_list:
                 url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/topics/{topic_str}"
                 headers_dict = {"Content-Type": "application/json"}
-                delete(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+                delete(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
         #
         return topic_str_list
 
@@ -276,7 +301,7 @@ class RestProxyAdmin(KafkaAdmin):
         #
         url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/topics"
         headers_dict = {"Content-Type": "application/json"}
-        response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+        response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
         kafkaTopic_dict_list = response_dict["data"]
         topic_str_list = [kafkaTopic_dict["topic_name"] for kafkaTopic_dict in kafkaTopic_dict_list]
         #
@@ -297,7 +322,7 @@ class RestProxyAdmin(KafkaAdmin):
         #
         url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/topics"
         headers_dict = {"Content-Type": "application/json"}
-        response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+        response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
         kafkaTopic_dict_list = response_dict["data"]
         #
         topic_str_partitions_int_dict = {kafkaTopic_dict["topic_name"]: kafkaTopic_dict["partitions_count"] for kafkaTopic_dict in kafkaTopic_dict_list if any(fnmatch(kafkaTopic_dict["topic_name"], pattern_str) for pattern_str in pattern_str_or_str_list)}
@@ -309,7 +334,7 @@ class RestProxyAdmin(KafkaAdmin):
                 for partition_int in range(topic_str_partitions_int_dict[topic_str]):
                     url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/topics/{topic_str}/partitions/{partition_int}/replicas"
                     headers_dict = {"Content-Type": "application/json"}
-                    response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+                    response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
                     kafkaReplica_dict_list = response_dict["data"]
                     #
                     if partition_int in partition_int_partition_dict_dict:
@@ -360,7 +385,7 @@ class RestProxyAdmin(KafkaAdmin):
             for partition_int in range(partitions_int):
                 url_str = f"{rest_proxy_url_str}/topics/{topic_str}/partitions/{partition_int}/offsets"
                 headers_dict = {"Content-Type": "application/vnd.kafka.v2+json"}
-                response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+                response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
                 topic_str_partition_int_offsets_tuple_dict_dict[topic_str][partition_int] = (response_dict["beginning_offset"], response_dict["end_offset"])
         #
         return topic_str_partition_int_offsets_tuple_dict_dict
@@ -374,23 +399,23 @@ class RestProxyAdmin(KafkaAdmin):
         #
         if len(pattern_str_list) == 1 and not(is_pattern(pattern_str_list[0])):
             url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/consumer-groups/{pattern_str_list[0]}"
-            response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+            response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
             kafkaConsumerGroup_dict_list = [response_dict]
         else:
             url_str = f"{rest_proxy_url_str}/v3/clusters/{self.cluster_id_str}/consumer-groups"
-            response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries=self.restproxy_obj.requests_num_retries())
+            response_dict = get(url_str, headers_dict, auth_str_tuple=auth_str_tuple, retries_int=self.restproxy_obj.requests_num_retries(), debug_bool=self.storage_obj.verbose() >= 2)
             kafkaConsumerGroup_dict_list = response_dict["data"]
         #
         return kafkaConsumerGroup_dict_list
 
 #
 
-def kafkaAcl_dict_to_dict(kafkaAcl_dict):
-    dict = {"restype": kafkaAcl_dict["resource_type"],
-            "name": kafkaAcl_dict["resource_name"],
-            "resource_pattern_type": kafkaAcl_dict["pattern_type"],
-            "principal": kafkaAcl_dict["principal"],
-            "host": kafkaAcl_dict["host"],
-            "operation": kafkaAcl_dict["operation"],
-            "permission_type": kafkaAcl_dict["permission"]}
-    return dict
+def kafkaAcl_dict_to_acl_dict(kafkaAcl_dict):
+    acl_dict = {"resource_type": kafkaAcl_dict["resource_type"].lower(),
+                "name": kafkaAcl_dict["resource_name"],
+                "pattern_type": kafkaAcl_dict["pattern_type"].lower(),
+                "principal": kafkaAcl_dict["principal"],
+                "host": kafkaAcl_dict["host"],
+                "operation": kafkaAcl_dict["operation"].lower(),
+                "permission_type": kafkaAcl_dict["permission"].lower()}
+    return acl_dict
